/*
 * filename: src/conf_parse.c
 * author: Pablo Yanez Trujillo <yanezp@imtek.de>
 */

#include <gutils.h>
#include <stdio.h>
#include <string.h>

static int varval_split(GString* source, GString* variable, GString* value)
{
	char* str, *tmp;
	int old;

	str = source->str;

	tmp = strchr(str, '=');


	if(!tmp || (str == tmp) || (tmp == str + source->len - 1))
	{
		g_string_free(variable, TRUE);
		g_string_free(value, TRUE);
		return 0;
	}

	old = *tmp;
	*tmp = 0;

	variable = g_string_append(variable, str);
	variable = g_string_trim(variable);

	*tmp = old;

	tmp++;

	value = g_string_append(value, tmp);
	value = g_string_trim(value);

	return 1;
}

char* conf_parse()
{
	FILE* buffer;
	GString* line, *variable, *value;
	int c, counter=0;

	buffer = fopen("/etc/aof-db.conf", "r");

	if(!buffer)
	{
		fprintf(stderr, "/etc/aof-db.conf cannot be read/opened. Make sure that you have aof-db installed and configured.\n");
		return NULL;
	}

	line = g_string_new("");

	if(!line)
	{
		fprintf(stderr, "Not enough memory\n");
		return 0;
	}

	while(EOF != (c = fgetc(buffer)))
	{
		if(c == '\n')
		{
			counter++;
			line = g_string_trim(line);

			if(strcmp(line->str, "") && (line->str[0] != '#'))
			{
				variable = g_string_new("");
				if(!variable)
				{
					fprintf(stderr, "Not enough memory\n");
					g_string_free(line, TRUE);
					return 0;
				}
				value = g_string_new("");
				if(!value)
				{
					fprintf(stderr, "Not enough memory\n");
					g_string_free(line, TRUE);
					g_string_free(variable, TRUE);
					return 0;
				}
				
				if(!varval_split(line, variable, value))
				{
					fprintf(stderr, "Parse error: /etc/aof-db.conf[%d] --> cannot read configuration file properly\n", counter);
					g_string_free(line, TRUE);
					return NULL;
				}

				if(!strcmp(variable->str, "DATABASE"))
				{
					g_string_free(line, TRUE);
					g_string_free(variable, TRUE);
					return g_string_free(value, FALSE);
				}

				g_string_free(variable, TRUE);
				g_string_free(value, TRUE);

			}

			g_string_free(line, TRUE);
			line = g_string_new("");
		}

		line = g_string_append_c(line, c);
	}

	g_string_free(line, TRUE);	
	fclose(buffer);
	return NULL;
}
