/*
 * filename: src/gutils.h
 * author: Pablo Yanez Trujillo <yanezp@imtek.de>
 */

/* This file is an extension of the GTK+ GLib.
 * This file contains functions that the GTK+ GLib does not
 * contain on their official releases (but should have)
 *
 * If you add some new functions then feel free to add your
 * name here
 *
 * Author(s): Pablo Yanez Trujillo <yanezp@imtek.de>
 *
 */

#ifndef AOFGUI_GUTILS_H
#define AOFGUI_GUTILS_H

#include <glib.h>
#include <ctype.h> /* for isspace, g_ascii_isspace is not quite what I need */


/*
 * GString* g_string_ltrim(GString* string)
 *
 * Searches for the first non-empty (using isspace) character from the left side.
 * When it is found the whole string after that character is moved to the first
 * place. The str field of GString won't change the pointer.
 *
 * Returns: the GString
 */
GString* g_string_ltrim(GString* string);

/*
 * GString* g_string_rtrim(GString* string)
 *
 * Searches for the first non-empty (using isspace) character from the right side.
 * When it is found then the next character is set to '\0'.
 * The str field of GString won't change the pointer.
 *
 * Returns: the GString
 */
GString* g_string_rtrim(GString* string);

/*
 * GString* g_string_trim(GString* string)
 *
 * Executes g_string_ltrim and then g_string_rtrim on "string"
 *
 * Returns: the GString
 */
GString* g_string_trim(GString* string);

/*
 * GString* g_string_iso_to_utf8(const gchar* string)
 *
 * Converts a string in ISO-8859-1 into a one in UTF-8. It takes
 * only '\0' terminated string.
 *
 * Returns: a GString in UTF-8 format
 */
GString* g_string_iso_to_utf8(const gchar* string);

/*
 * GString* g_string_utf8_to_iso(const gchar* string)
 *
 * Converts a string in UTF-( into one in ISO-8859-1. It takes
 * only '\0' terminated string.
 *
 * Returns: a GString in ISO-8859-1 format
 */
GString* g_string_utf8_to_iso(const gchar* string);

/*
 * void g_list_string_free(GList* list);
 *
 * Equivalent to g_list_free. 
 * g_string_fee(...,TRUE) is executed on each
 * element of the list
 */
void g_list_string_free(GList* list);


#endif
