/*
 * filename: main.c
 * author: Pablo Yanez Trujillo <yanezp@imtek.de>
 */

#ifndef GLADE_FILE
	#define GLADE_FILE "!%/)?'"
#endif

#ifndef HAVE_CONFIG_H
#include <config.h>
#else
#define PACKAGE "aof-gui"
#endif

#include <stdio.h>
#include <stdlib.h>

#include <sqlite3.h>
#include <gtk/gtk.h>
#include <glade/glade.h>

#include <gutils.h>
#include "arg_parse.h"
#include "conf_parse.h"
#include "db.h"
#include "callbacks.h"
#include "gtk_common.h"

static void createSpeeds()
{
	/* it would be better if aof-gui determines by itself which
	 * speeds are available. In the first version I know very
	 * well which DVD writer use will use so I know them exactly.
	 * aof-burn hdc # cat /proc/ide/hdc/model 
	 * HL-DT-ST DVDRAM GSA-4167B
	 */

	__cd_speed = g_list_append(__cd_speed, g_string_new("Auto"));
	__cd_speed = g_list_append(__cd_speed, g_string_new("4X"));
	__cd_speed = g_list_append(__cd_speed, g_string_new("8X"));
	__cd_speed = g_list_append(__cd_speed, g_string_new("16X"));
	__cd_speed = g_list_append(__cd_speed, g_string_new("24X"));
	__cd_speed = g_list_append(__cd_speed, g_string_new("32X"));
	__cd_speed = g_list_append(__cd_speed, g_string_new("40X"));
	__cd_speed = g_list_append(__cd_speed, g_string_new("48X"));

	__dvd_speed = g_list_append(__dvd_speed, g_string_new("Auto"));
	__dvd_speed = g_list_append(__dvd_speed, g_string_new("2X"));
	__dvd_speed = g_list_append(__dvd_speed, g_string_new("4X"));
	__dvd_speed = g_list_append(__dvd_speed, g_string_new("8X"));
	__dvd_speed = g_list_append(__dvd_speed, g_string_new("12X"));
	__dvd_speed = g_list_append(__dvd_speed, g_string_new("16X"));
}

int main(int argc, char *argv[])
{
	int parse;
	const char *poolmgr = NULL, *glade_file = NULL;
	char* database;
	FILE* f;
	GtkTreeView* view = NULL;
	GtkWidget *combo = NULL;
	GtkImage *poolmgr_img = NULL;

	__xml = NULL;
	__categories = NULL;
	__images = NULL;
	__cd_speed = NULL;
	__dvd_speed = NULL;
	__last_type = NULL;


	if(GLADE_FILE == "!%/)?'")
	{
		fprintf(stderr, "The binaries were not compiled properly. Please recompile aof-gui.\n");
		return EXIT_FAILURE;
	}

	gtk_init(&argc, &argv);
	
#ifdef DEVELOP_VERSION
	glade_file = DEVELOP_VERSION "/aof-gui.glade";
	poolmgr = DEVELOP_VERSION "/pixmaps/poolmgr.png";
#else
	glade_file = GLADE_FILE "/aof-gui.glade";
	poolmgr = PACKAGE_DATA_DIR "/" PACKAGE "/pixmaps/poolmgr.png";
#endif
        
	if(!(parse = arg_parse(argc, argv)))
		return EXIT_FAILURE;

	if(parse == 2)
		return EXIT_SUCCESS;

	database = conf_parse();

	if(!database)
		return EXIT_FAILURE;

	f = fopen(glade_file, "r");

	if(!f)
	{
		fprintf(stderr, "GUI file cannot be read. Cannot open '%s'\n", glade_file);
		free(database);
		return EXIT_FAILURE;
	}

	fclose(f);

	__db = db_connect(database);

	if(!__db)
	{
		free(database);
		return EXIT_FAILURE;
	}
	
	glade_init();

	createSpeeds();

	__categories = get_categories();

	__xml = glade_xml_new(glade_file, "mainWindow", NULL);
        
	glade_xml_signal_autoconnect(__xml);

	/* prepare category list */

	combo = glade_xml_get_widget(__xml, "optCategories");
	gtk_fill_combobox(GTK_COMBO_BOX(combo), __categories, 0);

	view = GTK_TREE_VIEW(glade_xml_get_widget(__xml, "imageView"));
	gtk_fill_treeview(view, __images);

	poolmgr_img = GTK_IMAGE(glade_xml_get_widget(__xml, "imgPoolmgr"));

	gtk_image_set_from_file(poolmgr_img, poolmgr);

	gtk_main();

	free(database);
	sqlite3_close(__db);

	g_list_string_free(__categories);
	g_list_string_free(__images);
	g_list_string_free(__cd_speed);
	g_list_string_free(__dvd_speed);

	return EXIT_SUCCESS;
}
